%define anolis_release 3

# With annobin enabled, CRIU does not work anymore. It seems CRIU's
# parasite code breaks if annobin is enabled.
%undefine _annotated_build

# Disable automatic call to the set_build_flags macro
# at the beginning of the build, check, and install.
%undefine _auto_set_build_flags

Name: criu
Version: 3.17.1
Release: %{anolis_release}%{?dist}
Summary: Tool for Checkpoint/Restore in User-space
License: GPLv2
URL: http://criu.org/
Source0: https://github.com/checkpoint-restore/criu/archive/v%{version}/criu-%{version}.tar.gz
Source1: criu-tmpfiles.conf

# backport from upstream to fix build failed with glibc-2.36
Patch1: 0001-rseq-fix-headers-conflict-on-Mariner-GNU-Linux.patch
Patch2: 0002-criu-fix-conflicting-headers.patch
Patch3: 0003-mount-add-definition-for-FSOPEN_CLOEXEC.patch
Patch4: 0004-use-pip-install-instead-of-setup.py-install.patch

BuildRequires: gcc
BuildRequires: systemd
BuildRequires: libnet-devel
BuildRequires: protobuf-devel protobuf-c-devel python3-devel libnl3-devel libcap-devel
BuildRequires: python3-setuptools
BuildRequires: python3-pip
BuildRequires: python3-wheel
BuildRequires: asciidoctor
BuildRequires: perl-interpreter
BuildRequires: libselinux-devel
BuildRequires: gnutls-devel
# Checkpointing containers with a tmpfs requires tar
Recommends: tar
BuildRequires: make

%description
criu is the user-space part of Checkpoint/Restore in User-space
(CRIU), a project to implement checkpoint/restore functionality for
Linux in user-space.

%package devel
Summary: Header files and libraries for %{name}
Requires: %{name} = %{version}-%{release}

%description devel
This package contains header files and libraries for %{name}.

%package libs
Summary: Libraries for %{name}
Requires: %{name} = %{version}-%{release}

%description libs
This package contains the libraries for %{name}

%package -n python3-%{name}
%{?python_provide:%python_provide python3-%{name}}
Summary: Python bindings for %{name}
Requires: python3-protobuf
Obsoletes: python2-criu < 3.10-1

%description -n python3-%{name}
python3-%{name} contains Python bindings for %{name}.

%package -n crit
Summary: CRIU image tool
Requires: python3-%{name} = %{version}-%{release}

%description -n crit
crit is a tool designed to decode CRIU binary dump files and show
their content in human-readable form.

%package -n criu-ns
Summary: Tool to run CRIU in different namespaces
Requires: %{name} = %{version}-%{release}

%description -n criu-ns
The purpose of the criu-ns wrapper script is to enable restoring a process
tree that might require a specific PID that is already used on the system.
This script can help to workaround the so called "PID mismatch" problem.

%package doc
Summary: Doc files for CRIU
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
Doc files for CRIU

%prep
%autosetup -p1

%build
# This package calls LD directly without specifying the LTO plugins.  Until
# that is fixed, disable LTO.
%define _lto_cflags %{nil}

CFLAGS+=`echo %{optflags} | sed -e 's,-fstack-protector\S*,,g'` make V=1 WERROR=0 PREFIX=%{_prefix} RUNDIR=/run/criu PYTHON=python3
make docs V=1

%install
make install-criu DESTDIR=$RPM_BUILD_ROOT PREFIX=%{_prefix} LIBDIR=%{_libdir}
make install-lib DESTDIR=$RPM_BUILD_ROOT PREFIX=%{_prefix} LIBDIR=%{_libdir} PYTHON=python3
make install-man DESTDIR=$RPM_BUILD_ROOT PREFIX=%{_prefix} LIBDIR=%{_libdir}

mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 0644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -d -m 0755 %{buildroot}/run/%{name}/

rm -f $RPM_BUILD_ROOT%{_mandir}/man1/amdgpu_plugin.1

# remove static lib
rm -f $RPM_BUILD_ROOT%{_libdir}/libcriu.a

%generate_compatibility_deps

%files
%{_sbindir}/%{name}
%{abidir}/%{name}-option.list
%doc %{_mandir}/man8/criu.8*
%doc %{_mandir}/man1/compel.1*
%{_libexecdir}/%{name}
%dir /run/%{name}
%{_tmpfilesdir}/%{name}.conf
%doc COPYING

%files devel
%{_includedir}/criu
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files libs
%dir %{abidir}
%{_libdir}/*.so.*
%{abidir}/lib%{name}.dump

%files -n python3-%{name}
%{python3_sitelib}/pycriu/*
%{python3_sitelib}/*dist-info

%files -n crit
%{_bindir}/crit
%doc %{_mandir}/man1/crit.1*

%files -n criu-ns
%{_sbindir}/criu-ns
%doc %{_mandir}/man1/criu-ns.1*

%files doc
%doc README.md INSTALL.md CONTRIBUTING.md MAINTAINERS_GUIDE.md

%changelog
* Mon Mar 11 2024 Bo Ren <rb01097748@alibaba-inc.com> - 3.17.1-3
- Rebuild with python3.11
- use pip install instead of setup.py install

* Mon Feb 13 2023 yuanhui <yuanhui@linux.alibaba.com> - 3.17.1-2
- add abi files

* Thu Sep 1 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.17.1-1
- update to 3.17.1

* Thu Mar 10 2022 Yuanhong Peng <yummypeng@linux.alibaba.com> - 3.16.1-1
- Init from upstream v3.16.1
